"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SQLiteSchema = void 0;
const adapter_base_1 = require("@graphql-debugger/adapter-base");
const build_1 = require("../../../../schemas/build");
const prisma_1 = require("../prisma");
class SQLiteSchema extends adapter_base_1.BaseSchema {
    constructor() {
        super();
    }
    async createOne({ data }) {
        const result = await prisma_1.prisma.$transaction(async () => {
            const schema = await prisma_1.prisma.schema.findFirst({
                where: {
                    hash: data.hash,
                },
            });
            if (schema) {
                return false;
            }
            await prisma_1.prisma.schema.create({
                data: {
                    hash: data.hash,
                    typeDefs: data.schema,
                },
            });
            return true;
        });
        return result;
    }
    async findMany(args = {}) {
        const where = {
            ...(args.where?.id ? { id: args.where.id } : {}),
            ...(args.where?.schemaHashes
                ? { hash: { in: args.where.schemaHashes } }
                : {}),
        };
        const schemas = await prisma_1.prisma.schema.findMany({
            orderBy: { createdAt: "desc" },
            where,
        });
        const response = schemas.map((schema) => ({
            id: schema.id,
            name: schema.name,
            hash: schema.hash,
            typeDefs: schema.typeDefs,
            traceGroups: [],
            createdAt: schema.createdAt.toISOString(),
        }));
        const parsed = build_1.SchemaSchema.array().parse(response);
        return parsed;
    }
    async findFirst({ where, options, }) {
        const schema = await prisma_1.prisma.schema.findFirst({
            where: {
                ...(where?.hash ? { hash: where.hash } : {}),
            },
            include: {
                ...(options?.includeTraces ? { traceGroups: true } : {}),
            },
        });
        if (!schema) {
            return null;
        }
        const response = {
            id: schema.id,
            name: schema.name,
            hash: schema.hash,
            typeDefs: schema.typeDefs,
            traceGroups: (schema.traceGroups || []).map((traceGroup) => ({
                id: traceGroup.id,
                schemaId: traceGroup.schemaId,
                traceId: traceGroup.traceId,
                spans: [],
            })),
            createdAt: schema.createdAt.toISOString(),
        };
        const parsed = build_1.SchemaSchema.parse(response);
        return parsed;
    }
    async upsert({ where, input, }) {
        const schema = await prisma_1.prisma.schema.upsert({
            where: {
                hash: where.hash,
            },
            create: {
                hash: input.hash,
                typeDefs: input.typeDefs,
            },
            update: {
                hash: input.hash,
                typeDefs: input.typeDefs,
            },
        });
        const response = {
            id: schema.id,
            name: schema.name,
            hash: schema.hash,
            typeDefs: schema.typeDefs,
            traceGroups: [],
            createdAt: schema.createdAt.toISOString(),
        };
        const parsed = build_1.SchemaSchema.parse(response);
        return parsed;
    }
}
exports.SQLiteSchema = SQLiteSchema;
